pub struct PullReport {
pub frames_pulled: u64,
pub checkpoint_seq: u32,
pub appliers_fanned: usize,
}Expand description
What a WalPuller::pull_once call did.
Fields
frames_pulled: u64Frames downloaded from the object store and fanned out this call.
Each was downloaded exactly once regardless of appliers_fanned.
checkpoint_seq: u32The source’s checkpoint_seq as of this call (0 if nothing has ever
been pulled and there are still no generation manifests to read).
appliers_fanned: usizeAttached-applier count at the time of this call.